@@ -64,9 +64,9 @@ class Embed:
             Returns the total size of the embed.
             Useful for checking if it's within the 6000 character limit.
 
-    Certain properties return an ``EmbedProxy``. Which is a type
-    that acts similar to a regular :class:`dict` except access the attributes
-    via dotted access, e.g. ``embed.author.icon_url``. If the attribute
+    Certain properties return an ``EmbedProxy``, a type
+    that acts similar to a regular :class:`dict` except using dotted access,
+    e.g. ``embed.author.icon_url``. If the attribute
     is invalid or empty, then a special sentinel value is returned,
     :attr:`Embed.Empty`.
 
@@ -87,10 +87,9 @@ class Embed:
     url: :class:`str`
         The URL of the embed.
         This can be set during initialisation.
-    timestamp: `datetime.datetime`
+    timestamp: :class:`datetime.datetime`
         The timestamp of the embed content. This could be a naive or aware datetime.
-        This can be set during initialisation.
-    colour: :class:`Colour` or :class:`int`
+    colour: Union[:class:`Colour`, :class:`int`]
         The colour code of the embed. Aliased to ``color`` as well.
         This can be set during initialisation.
     Empty
@@ -422,6 +421,39 @@ class Embed:
             self._fields = [field]
 
         return self
+   
+    def insert_field_at(self, index, *, name, value, inline=True):
+        """Inserts a field before a specified index to the embed.
+        
+        This function returns the class instance to allow for fluent-style
+        chaining.
+        
+        .. versionadded:: 1.2.0
+        
+        Parameters
+        -----------
+        index: :class:`int`
+            The index of where to insert the field.
+        name: :class:`str`
+            The name of the field.
+        value: :class:`str`
+            The value of the field.
+        inline: :class:`bool`
+            Whether the field should be displayed inline.
+        """
+
+        field = {
+            'inline': inline,
+            'name': str(name),
+            'value': str(value)
+        }
+
+        try:
+            self._fields.insert(index, field)
+        except AttributeError:
+            self._fields = [field]
+
+        return self
 
     def clear_fields(self):
         """Removes all fields from this embed."""
